<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2006 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Maintenance.mtc.test.php 3401 2005-06-23 13:01:54Z andrew $
*/

require_once MAX_PATH . '/lib/max/core/ServiceLocator.php';
require_once MAX_PATH . '/lib/Max.php';
require_once MAX_PATH . '/lib/max/DB.php';
require_once MAX_PATH . '/lib/max/Maintenance.php';
require_once MAX_PATH . '/lib/max/Maintenance/Forecasting/Channel/Limitations.php';
require_once MAX_PATH . '/lib/max/Table/Core.php';
require_once 'Date.php';

/**
 * A class for testing the Maintenance class.
 *
 * @package    MaxMaintenance
 * @subpackage TestSuite
 * @author     Radek Maciaszek <radek@m3.net>
 */
class Maintenance_TestOfLimitations extends UnitTestCase
{
    var $errorLevel;
    
    function setUp()
    {
        $this->errorLevel = error_reporting(E_ALL);
    }
    
    function tearDown()
    {
        error_reporting($this->errorLevel);
    }
    
    /**
     * The constructor method.
     */    
    function Maintenance_TestOfLimitations()
    {        
        $this->UnitTestCase();
        Mock::generate('MAX_Maintenance_Forecasting_Channel_Limitations');
        $oLimitations = &new MockMAX_Maintenance_Forecasting_Channel_Limitations($this);
        $oServiceLocator = &ServiceLocator::instance();
        $oServiceLocator->register('MAX_Maintenance_Forecasting_Channel_Limitations', $oLimitations);
    }
    
    /**
     * Test if limitation is translated into sql limitation
     */
    function testIsSqlLimitationExists()
    {
        $limitations = new MAX_Maintenance_Forecasting_Channel_Limitations();
        $ret = $limitations->isSqlLimitationExists('boo');
        $this->assertFalse($ret);
        
        // at least country code should be implemented
        $ret = $limitations->isSqlLimitationExists('country_code');
        $this->assertTrue($ret);
    }
    
    /**
     * Test if limitation is translated into sql limitation
     */
    function testGetSqlLimitation()
    {
        $data = null;
        $comparison = 'and';
        
        $limitations = new MAX_Maintenance_Forecasting_Channel_Limitations();
        $ret = $limitations->getSqlLimitation('boo', $data, $comparison);
        $this->assertNull($ret);
        
        // at least country code should be implemented
        $ret = $limitations->getSqlLimitation('country_code', $data, $comparison);
        $this->assertTrue(!empty($ret));
    }
    
    /**
     * Test if limitation is translated into sql limitation
     */
    function testGetPhpLimitation()
    {
        $data = null;
        $comparison = 'and';
        
        $limitations = new MAX_Maintenance_Forecasting_Channel_Limitations();
        $ret = $limitations->getPhpLimitation('boo', $data, $comparison);
        $this->assertNull($ret);
        
        // at least country code should be implemented
        $ret = $limitations->getPhpLimitation('country_code', $data, $comparison);
        $this->assertTrue(!empty($ret));
    }
    
}

?>
